package com.jiuqi.syntax;

import java.math.BigDecimal;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

/* loaded from: com_jiuqi_syntax.jar:com/jiuqi/syntax/CommonData.class */
public class CommonData implements Cloneable {
    public static final int NULL_TYPE = 0;
    public static final int INT_TYPE = 1;
    public static final int REAL_TYPE = 2;
    public static final int STRING_TYPE = 3;
    public static final int EXP_TYPE = 4;
    public static final int BOOL_TYPE = 5;
    public static final int DATE_TYPE = 6;
    public static final int MEMO_TYPE = 7;
    public static final int OBJECT_TYPE = 8;
    public static final int DECIMAL_TYPE = 10;
    public int type = 0;
    public boolean isNull = false;
    public int cdInt = 0;
    public double cdReal = 0.0d;
    public String cdString = "";
    public boolean cdBool = false;
    public Calendar cdDate = null;
    public Object cdObject = null;
    public BigDecimal cdDecimal = null;
    public static int CD_NEW_COUNT = 0;
    public static int CD_LIVE_COUNT = 0;
    protected static final DataOperator[] operators = new DataOperator[16];

    static {
        operators[0] = new DataOperator() { // from class: com.jiuqi.syntax.CommonData.1
            @Override // com.jiuqi.syntax.CommonData.DataOperator
            public int compare(CommonData v1, CommonData v2, double delta) {
                return 0;
            }
        };
        operators[1] = new DataOperator() { // from class: com.jiuqi.syntax.CommonData.2
            @Override // com.jiuqi.syntax.CommonData.DataOperator
            public int compare(CommonData v1, CommonData v2, double delta) {
                return v1.cdInt - v2.cdInt;
            }
        };
        operators[2] = new DataOperator() { // from class: com.jiuqi.syntax.CommonData.3
            @Override // com.jiuqi.syntax.CommonData.DataOperator
            public int compare(CommonData v1, CommonData v2, double delta) {
                if (delta == 0.0d) {
                    if (Math.abs(v1.cdReal - v2.cdReal) < 1.0E-5d) {
                        return 0;
                    }
                    if (v1.cdReal > v2.cdReal) {
                        return 1;
                    }
                    return -1;
                }
                if (Math.abs(v1.cdReal - v2.cdReal) < delta) {
                    return 0;
                }
                if (v1.cdReal > v2.cdReal) {
                    return 1;
                }
                return -1;
            }
        };
        operators[3] = new DataOperator() { // from class: com.jiuqi.syntax.CommonData.4
            @Override // com.jiuqi.syntax.CommonData.DataOperator
            public int compare(CommonData v1, CommonData v2, double delta) {
                return v1.cdString.compareTo(v2.cdString);
            }
        };
        operators[4] = operators[3];
        operators[5] = new DataOperator() { // from class: com.jiuqi.syntax.CommonData.5
            @Override // com.jiuqi.syntax.CommonData.DataOperator
            public int compare(CommonData v1, CommonData v2, double delta) {
                return v1.cdBool == v2.cdBool ? 0 : 255;
            }
        };
        operators[6] = new DataOperator() { // from class: com.jiuqi.syntax.CommonData.6
            @Override // com.jiuqi.syntax.CommonData.DataOperator
            public int compare(CommonData v1, CommonData v2, double delta) {
                if (v1.cdDate == null || v2.cdDate == null) {
                    return 255;
                }
                if (v1.cdDate.before(v2.cdDate)) {
                    return -1;
                }
                if (v1.cdDate.after(v2.cdDate)) {
                    return 1;
                }
                return 0;
            }
        };
        operators[10] = new DataOperator() { // from class: com.jiuqi.syntax.CommonData.7
            @Override // com.jiuqi.syntax.CommonData.DataOperator
            public int compare(CommonData v1, CommonData v2, double delta) {
                if (v1.cdDecimal == null || v2.cdDecimal == null) {
                    return 255;
                }
                if (delta == 0.0d) {
                    delta = 1.0E-5d;
                }
                BigDecimal comResult = v1.cdDecimal.subtract(v2.cdDecimal);
                if (comResult.abs().compareTo(new BigDecimal(delta)) < 0) {
                    return 0;
                }
                if (comResult.signum() > 0) {
                    return 1;
                }
                return -1;
            }
        };
    }

    public double getIntRealValue() {
        if (this.type == 1) {
            return this.cdInt;
        }
        if (this.type == 2) {
            return this.cdReal;
        }
        return 0.0d;
    }

    public CommonData() {
        CD_NEW_COUNT++;
        CD_LIVE_COUNT++;
    }

    public Object clone() {
        CommonData d = new CommonData();
        assignTo(d);
        return d;
    }

    public void assign(CommonData source) {
        this.type = source.type;
        this.isNull = source.isNull;
        initNullValue();
        if (!this.isNull) {
            switch (this.type) {
                case 0:
                case 9:
                default:
                    return;
                case 1:
                    this.cdInt = source.cdInt;
                    return;
                case 2:
                    this.cdReal = source.cdReal;
                    return;
                case 3:
                    this.cdString = source.cdString;
                    return;
                case 4:
                    this.cdString = source.cdString;
                    return;
                case 5:
                    this.cdBool = source.cdBool;
                    return;
                case 6:
                    this.cdDate = source.cdDate;
                    return;
                case 7:
                    this.cdObject = source.cdObject;
                    break;
                case 8:
                    break;
                case 10:
                    this.cdDecimal = source.cdDecimal;
                    return;
            }
            this.cdObject = source.cdObject;
        }
    }

    public void assignTo(CommonData dest) {
        dest.assign(this);
    }

    public void initValue() {
        switch (this.type) {
            case 0:
            case 9:
            default:
                return;
            case 1:
                this.cdInt = 0;
                return;
            case 2:
                this.cdReal = 0.0d;
                return;
            case 3:
                this.cdString = "";
                return;
            case 4:
                this.cdString = "";
                return;
            case 5:
                this.cdBool = false;
                return;
            case 6:
                this.cdDate = null;
                return;
            case 7:
                this.cdObject = null;
                return;
            case 8:
                this.cdObject = null;
                return;
            case 10:
                this.cdDecimal = new BigDecimal(0);
                return;
        }
    }

    public void initNullValue() {
        if (this.isNull) {
            initValue();
        }
    }

    public int compareTo(CommonData other) {
        return compareTo(other, 0.0d);
    }

    public final int compareTo(CommonData other, double diffValue) {
        if (other == null || this.type != other.type) {
            return 255;
        }
        if (this.isNull && other.isNull) {
            return 0;
        }
        if (this.isNull != other.isNull) {
            initNullValue();
            other.initNullValue();
        }
        if (operators[this.type] == null) {
            return 255;
        }
        return operators[this.type].compare(this, other, diffValue);
    }

    public boolean equals(CommonData other) {
        return compareTo(other, 0.0d) == 0;
    }

    public boolean equals(CommonData other, double diffValue) {
        return compareTo(other, diffValue) == 0;
    }

    public String toString() {
        String s = new String();
        switch (this.type) {
            case 0:
                s = "";
                break;
            case 1:
                s = String.valueOf(this.cdInt);
                break;
            case 2:
                s = String.valueOf(this.cdReal);
                break;
            case 3:
                s = this.cdString;
                break;
            case 4:
                s = this.cdString;
                break;
            case 5:
                s = String.valueOf(this.cdBool);
                break;
            case 6:
                if (this.cdDate != null) {
                    s = this.cdDate.toString();
                    break;
                } else {
                    s = "";
                    break;
                }
            case 7:
                s = "";
                break;
            case 8:
                s = "";
                break;
            case 10:
                if (this.cdDecimal == null) {
                    s = "";
                    break;
                } else {
                    s = this.cdDecimal.toString();
                    break;
                }
        }
        return s;
    }

    public void setDateValue(Date dateValue) {
        this.type = 6;
        this.isNull = dateValue == null;
        if (!this.isNull && this.cdDate == null) {
            this.cdDate = new GregorianCalendar();
        }
        if (dateValue != null) {
            this.cdDate.setTime(dateValue);
        } else if (this.cdDate != null) {
            this.cdDate.clear();
        }
    }

    public Calendar getValidcdDate() {
        if (this.cdDate == null) {
            this.cdDate = Calendar.getInstance();
            this.cdDate.getTime().setTime(0L);
            this.cdDate.set(1, 1899);
            this.cdDate.set(2, 1);
            this.cdDate.set(5, 1);
        }
        return this.cdDate;
    }

    protected void finalize() throws Throwable {
        CD_LIVE_COUNT--;
        super.finalize();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* loaded from: com_jiuqi_syntax.jar:com/jiuqi/syntax/CommonData$DataOperator.class */
    public static abstract class DataOperator {
        public abstract int compare(CommonData commonData, CommonData commonData2, double d);

        protected DataOperator() {
        }
    }
}
